operator >= method
Check this Temperature has greater or equal measurment of other.
Implementation
bool operator >=(Temperature other) => compareTo(other) >= 0;
Check this Temperature has greater or equal measurment of other.
bool operator >=(Temperature other) => compareTo(other) >= 0;